Accessory function retrieving invalid values from messages returned by the UniProt API.
parse_messages(messages)a data.frame with invalid values (in column "value") and corresponding query field (in column "field"). NULL if no invalid values are identified.
character string containing the error messages returned by UniProt API